//
// This file contains model number definitions for the CUPS sample
// HP driver.
//
// Copyright 2007 by Apple Inc.
// Copyright 1997-2005 by Easy Software Products.
//
// Licensed under Apache License v2.0.  See the file "LICENSE" for more
// information.
//

#define HP_LASERJET	0		// HP LaserJet
#define HP_DESKJET	1		// HP DeskJet with simple color
#define HP_DESKJET2	2		// HP DeskJet with CRet color
